#
# spec file for package iodbc
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           iodbc
Version:        3.52.16
Release:        1.7
Summary:        ODBC compliant driver manager
License:        BSD-3-Clause OR LGPL-2.0-only
Group:          Development/Libraries/C and C++
URL:            http://www.iodbc.org/
Source:         https://download.sourceforge.net/iodbc/libiodbc-%{version}.tar.gz
BuildRequires:  pkgconfig(gtk+-2.0)

%description
The iODBC Driver Manager is an implementation of the SAG CLI and
ODBC compliant driver manager which allows developers to write ODBC
compliant applications that can connect to various databases using
appropriate backend drivers.

%package -n libiodbc-devel
Summary:        Headers for iODBC
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Requires:       libdrvproxy2 = %{version}
Requires:       libiodbc2 = %{version}
Requires:       libiodbcadm2 = %{version}
Requires:       pkgconfig(gtk+-2.0)

%description -n libiodbc-devel
This package contains headers for the iODBC Driver Manager.

%package -n libiodbc2
Summary:        Libraries needed to run iODBC
Group:          System/Libraries
Conflicts:      libiodbc3 <= 3.52.14

%description -n libiodbc2
The iODBC Driver Manager is an implementation of the SAG CLI andx
ODBC compliant driver manager which allows developers to write ODBC
compliant applications that can connect to various databases using
appropriate backend drivers.

This package provides the shared libraries needed by iODBC.

%package -n libdrvproxy2
Summary:        Administration library for iODBC
Group:          System/Libraries

%description -n libdrvproxy2
This package provides libdrvproxy for administering iODBC

%package -n libiodbcadm2
Summary:        Administration library for iODBC
Group:          System/Libraries

%description -n libiodbcadm2
This package provides libiodbcadm for administering iODBC

%package admin
Summary:        Administration tools for iODBC
Group:          Development/Libraries/C and C++

%description admin
The iODBC Driver Manager is an implementation of the SAG CLI and
ODBC compliant driver manager which allows developers to write ODBC
compliant applications that can connect to various databases using
appropriate backend drivers.

This package provides tools for configuring and administering iODBC.

%prep
%autosetup -n libiodbc-%{version} -p1

%build
%configure \
    --disable-static \
    --disable-libodbc \
    --disable-dependency-tracking

# Don't use rpath!
sed -i 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' libtool
sed -i 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' libtool
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%post   -n libiodbc2 -p /sbin/ldconfig
%postun -n libiodbc2 -p /sbin/ldconfig
%post   -n libiodbcadm2 -p /sbin/ldconfig
%postun -n libiodbcadm2 -p /sbin/ldconfig
%post   -n libdrvproxy2 -p /sbin/ldconfig
%postun -n libdrvproxy2 -p /sbin/ldconfig

%files
%license LICENSE
%{_bindir}/iodbctest
%{_bindir}/iodbctestw
%{_mandir}/man1/iodbctest.1*
%{_mandir}/man1/iodbctestw.1*

%files admin
%license LICENSE
%{_bindir}/iodbcadm-gtk
%{_mandir}/man1/iodbcadm-gtk.1*

%files -n libiodbc-devel
%license LICENSE LICENSE.LGPL LICENSE.BSD
%doc AUTHORS ChangeLog NEWS README
%doc etc/odbc.ini.sample
%doc etc/odbcinst.ini.sample
%{_bindir}/iodbc-config
%{_datadir}/libiodbc
%{_includedir}/iodbcext.h
%{_includedir}/iodbcinst.h
%{_includedir}/iodbcunix.h
%{_includedir}/isql.h
%{_includedir}/isqlext.h
%{_includedir}/isqltypes.h
%{_includedir}/odbcinst.h
%{_includedir}/sql.h
%{_includedir}/sqlext.h
%{_includedir}/sqltypes.h
%{_includedir}/sqlucode.h
%{_libdir}/libdrvproxy.so
%{_libdir}/libiodbc.so
%{_libdir}/libiodbcadm.so
%{_libdir}/libiodbcinst.so
%{_libdir}/pkgconfig/libiodbc.pc
%{_mandir}/man1/iodbc-config.1*

%files -n libiodbc2
%license LICENSE
%{_libdir}/libiodbc.so.*
%{_libdir}/libiodbcinst.so.*

%files -n libdrvproxy2
%license LICENSE
%{_libdir}/libdrvproxy.so.*

%files -n libiodbcadm2
%license LICENSE
%{_libdir}/libiodbcadm.so.*

%changelog
* Fri Sep 15 2023 Michael Vetter <mvetter@suse.com>
- Update to 3.52.16
  * Fixed issue with generic setup dialogs on macOS not saving values
  * Fixed issue when creating new DSN via generic setup dialogs
    on macOS BigSur
  * Fixed issue with new vertical layout for Alerts on macOS BigSur
  * Fixed support for modern limit path name size
  * Fixed SQLBindParameter trace when bind offset is in use (#80)
  * Fixed SQLGetInstalledDrivers single entry error (#79)
  * Fixed silent truncation of 'long' diagnostic messages in
    SQLGetDiagRec (#78)
  * Fixed missing comma (#72)
  * Fixed potential memory leak (#71)
  * Fixed truncation of SQL_C_WCHAR parameter value when
    BufferLength=0 and length=SQL_NTS (#68)
  * Fixed issue overriding SQL_DEFAULT_PARAM length indicator (#67)
  * Fixed issue with input parameter data when using parameter arrays (#66)
  * Fixed compiler warnings
  * Fixed version check of build tools
  * Updated documents
- Changelog from 3.52.15:
  * Added support for macOS Big Sur (11.x) on Apple Silicon using
    a universal build
  * Fixed title to show CPU architecture used
  * Fixed length of error message buffer
  * Fixed small portability issues
  * Removed support for Mac OS X Snow Leopard (10.6) and older
  * Removed deprecated iODBCcfmbridge for PPC
- Remove upstreamed fix-nonvoid-return.diff
* Tue Apr 26 2022 Jan Engelhardt <jengelh@inai.de>
- Resolve rpmlint report "libiodbc3.x86_64: E:
  shlib-policy-name-error SONAME: libiodbc.so.2, expected package
  suffix: 2"
* Mon May 31 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 3.52.14
  * Fixed: SQLSetEnvAttr doesn't return SQL_SUCCESS for option
    SQL_ATTR_APP_UNICODE_TYPE
  * Fixed: issue with switching ODBC driver to best supported
    Unicode codepage
  * Fixed: misprint in SQLBrowseConnect
  * Fixed: SQLGetConnectOption returned wrong value for
    SQL_CURRENT_QUALIFIER
  * Fixed: mixing calls to SQLFetchScroll with SQLFetch
  * Fixed: Misc Unicode issues
  * Added extra validation for SQLAllocHandle
  * Added missing define SQL_CONVERT_GUID
  * Fixed issue using heap after free in SQLConnect_internal
  * Fixed issue with global mutex
  * Fixed SQLSetStmtAttr to cache the correct values for
    SQL_ATTR_ROW_ARRAY_SIZE and SQL_ATTR_ROW_BIND_TYPE
  * Fixed format specifiers and some casts to fix trace output
  * Fixed missing check for section in SQLGetPrivateProfileString
  * Fixed non-void function needs to return a value
  * Fixed iODBC apps/frameworks CFBundleGetInfoString attribute
  * Fixed small memory leaks
- Split library packages, so other packages can require only
  needed ones
- Refresh fix-nonvoid-return.diff
- Drop config-h.diff
* Thu Jan 26 2017 adam.majer@suse.de
- Update to version 0.52.12:
  * Added 64bit version of the iODBC Administrator to configure
    and test DSNs on drivers that are only available in 64bit
    format
  * Documentation fixes
- Changes in version 0.52.11:
  * Added support for x86_64 to iODBC Demo
  * Fix crash ODBCdemo - error message overwrite stack data
  * Fix iODBCdemo issue with UID/PWD values
  * Fixed crash in iODBC DM on push of "Test" button when 64bit
    ODBC driver is used.
  * Fixed crash when create_dsnsetup fails to load the window.
  * Fixed crash when passing an empty connect string with no
    window handle
  * Fixed crash when passing an empty connect string with no
    window handle.
  * Fixed issue in SQLGetInfo
  * Fixed crash when create_dsnsetup fails to load the window
- fix-nonvoid-return.diff: submitted upstream
* Fri Mar 13 2015 tchvatal@suse.com
- Version bump to 0.52.10:
  * Fixed issue with ~/Library/ODBC/odbc[inst].ini on Mac OS X
  * Added build support for Mac OS X 10.10
  * Updated iODBC Administrator
  * Updated iODBC Demo
  * Fixed string truncation in Unicode <-> Ansi conversion on some API calls
* Wed Jan 21 2015 p.drouand@gmail.com
- Update to version 0.52.9
  * Added support for building on recent versions of Mac OS X
  * Fixed warnings from autoconf/automake
  * Fixed infinite loop in connection pool
  * Fixed compiler warnings
  * Fixed build dependency for make -jX
  * Fixed check for Unicode driver
  * Fixed issue calling SQLCancel from other thread
  * Fixed SQLInstallDriverEx when driver is readonly
- Use download Url as source
* Sat Jun 22 2013 jengelh@inai.de
- Set proper extension for tar archive
* Tue Nov 20 2012 cgiboudeaux@gmx.com
- Update to 3.52.8
  * Fixed issue with using buffer after free
  * Fixed use ssize_t where appropriate
  * Fixed issue with strlen if param can be NULL
  * Fixed use ssize_t for length of string
  * Fixed tracing SQLGetData using multiple chunks
  * Fixed problem tracing on big-endian machines
  * Fixed wrong type label
  * Fixed compiler warnings
* Wed Sep  5 2012 cfarrell@suse.com
- license update: LGPL-2.0 or BSD-3-Clause
  See COPYING file. Note that the only valid version of the LGPL for iodbc
  is the original ^library gpl^ - not version 2.1
* Tue Jun 26 2012 scorot@free.fr
- fix requirement of the devel package for SLE 11
* Mon Jun 25 2012 scorot@free.fr
- fix build on SLE 11
* Mon Jun 27 2011 toddrme2178@gmail.com
- Split doc package (fix for RPMLINT warning)
- Cleaned up spec file formatting
* Mon Jun 27 2011 toddrme2178@gmail.com
- Various RPMLINT fixes
- Clarified summaries and descriptions
* Sat Feb 26 2011 toddrme2178@gmail.com
- Update to 3.52.7
  * Added iODBC CFM Bridge
  * Added resizable windows and dialogs for GTK+
  * Added option in tracefile for sequence number ($S)
  * Added additional translations between ANSI and Unicode
  * Fixed if tracefile gets too big, continue in new tracefile
  * Fixed unload bug due to wrong pointer deref
  * Fixed Connection Pooling UI
  * Fixed checking odbc_ver on connect handle
  * Fixed packaging of runtime only libraries
  * Fixed porting issues
  * Fixed documentation
* Thu May 28 2009 llunak@suse.cz
- fix build with gcc4.4
* Thu May  7 2009 llunak@suse.cz
- Initial version
